==> custom_pages-v1.12.9.zip: custom_pages/messages/hu/model.php <==
<?php

return [
    'Abstract' => 'Összefoglaló',
    'Activate PHP based Pages and Snippets' => 'PHP alapú oldalak és kódrészletek (snippet) aktiválása',
    'Attach Files' => 'Csatolt fájlok',
    'Content' => 'Tartalom',
    'Empty <br />Container' => 'Üres <br />Tároló',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Ha nincs engedélyezve, a meglévő php oldalak továbbra is online maradnak, de nem hozhatók létre.',
    'Label' => 'Cimke',
    'Open in new window' => 'Megnyitás új ablakban',
    'PHP view path for custom space pages' => 'PHP megtekintési útvonal egyedi közösség-oldalakhoz',
    'PHP view path for custom space snippets' => 'PHP megtekintési útvonal egyedi kódrészletekhez (snippet)',
    'PHP view path for global custom pages' => 'PHP megtekintési útvonal globális egyedi oldalakhoz',
    'PHP view path for global custom snippets' => 'PHP megtekintési útvonal globális egyedi kódrészletekhez (snippet)',
    'Placeholder name' => 'Helykitöltő neve',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Az elem nevének legalább két karaktert kell tartalmaznia szóközök vagy különleges jelek nélkül, kivéve "_"',
    'The given element name is already in use for this template.' => 'A megadott elemnév már használatban van ehhez a sablonhoz.',
    'The given view file path does not exist.' => 'Az megadott nézet fájl elérési útja nem létezik.',
    'Url shortcut' => 'URL shortcut',
    'View' => 'Megtekintés',
    'Visibility' => 'Láthatóság',
    'page' => 'oldal',
    'snippet' => 'kódrészlet (snippet)',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/hu/model.php <==
<?php

return [
    'Abstract' => 'Összefoglaló',
    'Activate PHP based Pages and Snippets' => 'PHP alapú oldalak és kódrészletek (snippet) aktiválása',
    'Attach Files' => 'Csatolt fájlok',
    'Content' => 'Tartalom',
    'Empty <br />Container' => 'Üres <br />Tároló',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Ha nincs engedélyezve, a meglévő php oldalak továbbra is online maradnak, de nem hozhatók létre.',
    'Label' => 'Cimke',
    'Open in new window' => 'Megnyitás új ablakban',
    'PHP view path for custom space pages' => 'PHP megtekintési útvonal egyedi közösség-oldalakhoz',
    'PHP view path for custom space snippets' => 'PHP megtekintési útvonal egyedi kódrészletekhez (snippet)',
    'PHP view path for global custom pages' => 'PHP megtekintési útvonal globális egyedi oldalakhoz',
    'PHP view path for global custom snippets' => 'PHP megtekintési útvonal globális egyedi kódrészletekhez (snippet)',
    'Placeholder name' => 'Helykitöltő neve',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Az elem nevének legalább két karaktert kell tartalmaznia szóközök vagy különleges jelek nélkül, kivéve "_"',
    'The given element name is already in use for this template.' => 'A megadott elemnév már használatban van ehhez a sablonhoz.',
    'The given view file path does not exist.' => 'Az megadott nézet fájl elérési útja nem létezik.',
    'Url shortcut' => 'URL shortcut',
    'View' => 'Megtekintés',
    'Visibility' => 'Láthatóság',
    'page' => 'oldal',
    'snippet' => 'kódrészlet (snippet)',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
